package com.hungraim.ltc.controller;

import com.hungraim.ltc.util.CsoftSecurityUtil;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.security.oauth2.common.OAuth2AccessToken;
import org.springframework.security.oauth2.provider.endpoint.TokenEndpoint;
import org.springframework.web.bind.annotation.*;

import java.security.NoSuchAlgorithmException;
import java.security.Principal;
import java.util.Map;

/**
 * 认证中心
 *
 * @author hubin
 */
@RestController
@RequestMapping("/oauth")
@AllArgsConstructor
public class AuthController {
  private final TokenEndpoint tokenEndpoint;

  @PostMapping("/token")
  @SneakyThrows
  public Result<OAuth2AccessToken> postAccessToken(Principal principal, @RequestParam Map<String, String> parameters)  {
    String password = parameters.get("password");
    String decrypt = CsoftSecurityUtil.decryptRSADefault(password);
    parameters.put("password", decrypt);
    OAuth2AccessToken oAuth2AccessToken = tokenEndpoint.postAccessToken(principal, parameters).getBody();
    return Result.success(oAuth2AccessToken);
  }

  /**
   * 获取公钥
   * @return
   */
  @GetMapping("/genKeyPair")
  public Result<String> genKeyPair() {
    Map keyMap = CsoftSecurityUtil.createKeyPairs();
    return Result.success(keyMap.get(0).toString());
  }



}
